@@ -70,6 +70,15 @@ class CacheTestCase(unittest.TestCase):
         with self.assertRaises(ValueError):
             CachedSession(CACHE_NAME, backend='nonexistent')
 
+    @mock.patch('requests_cache.backends.registry')
+    def test_missing_backend_dependency(self, mocked_registry):
+        # Testing that the correct error is thrown when a user does not have
+        # the Python package `redis` installed.  We mock out the registry
+        # to simulate `redis` not being installed.
+        mocked_registry.__getitem__.side_effect = KeyError
+        with self.assertRaises(ImportError):
+            CachedSession(CACHE_NAME, backend='redis')
+
     def test_hooks(self):
         state = defaultdict(int)
         for hook in ('response',):  # TODO it's only one hook here
@@ -343,6 +352,109 @@ class CacheTestCase(unittest.TestCase):
             with self.assertRaises(Exception):
                 s.get(url)
 
+    def test_ignore_parameters_get(self):
+        url = httpbin("get")
+        ignored_param = "ignored"
+        usual_param = "some"
+        params = {ignored_param: "1", usual_param: "1"}
+
+        s = CachedSession(CACHE_NAME, CACHE_BACKEND,
+                          ignored_parameters=[ignored_param])
+
+        r = s.get(url, params=params)
+        self.assertIn(ignored_param, r.json()['args'].keys())
+        self.assertFalse(r.from_cache)
+
+        self.assertTrue(s.get(url, params=params).from_cache)
+
+        params[ignored_param] = "new"
+        self.assertTrue(s.get(url, params=params).from_cache)
+
+        params[usual_param] = "new"
+        self.assertFalse(s.get(url, params=params).from_cache)
+
+    def test_ignore_parameters_post(self):
+        url = httpbin("post")
+        ignored_param = "ignored"
+        usual_param = "some"
+        d = {ignored_param: "1", usual_param: "1"}
+
+        s = CachedSession(CACHE_NAME, CACHE_BACKEND,
+                          allowable_methods=('POST'),
+                          ignored_parameters=[ignored_param])
+
+        r = s.post(url, data=d)
+        self.assertIn(ignored_param, r.json()['form'].keys())
+        self.assertFalse(r.from_cache)
+
+        self.assertTrue(s.post(url, data=d).from_cache)
+
+        d[ignored_param] = "new"
+        self.assertTrue(s.post(url, data=d).from_cache)
+
+        d[usual_param] = "new"
+        self.assertFalse(s.post(url, data=d).from_cache)
+
+    def test_ignore_parameters_post_json(self):
+        url = httpbin("post")
+        ignored_param = "ignored"
+        usual_param = "some"
+        d = {ignored_param: "1", usual_param: "1"}
+
+        s = CachedSession(CACHE_NAME, CACHE_BACKEND,
+                          allowable_methods=('POST'),
+                          ignored_parameters=[ignored_param])
+
+        r = s.post(url, json=d)
+        self.assertIn(ignored_param, json.loads(r.json()['data']).keys())
+        self.assertFalse(r.from_cache)
+
+        self.assertTrue(s.post(url, json=d).from_cache)
+
+        d[ignored_param] = "new"
+        self.assertTrue(s.post(url, json=d).from_cache)
+
+        d[usual_param] = "new"
+        self.assertFalse(s.post(url, json=d).from_cache)
+
+    def test_ignore_parameters_post_raw(self):
+        url = httpbin("post")
+        ignored_param = "ignored"
+        raw_data = "raw test data"
+
+        s = CachedSession(CACHE_NAME, CACHE_BACKEND,
+                          allowable_methods=('POST'),
+                          ignored_parameters=[ignored_param])
+
+        self.assertFalse(s.post(url, data=raw_data).from_cache)
+        self.assertTrue(s.post(url, data=raw_data).from_cache)
+
+        raw_data = "new raw data"
+        self.assertFalse(s.post(url, data=raw_data).from_cache)
+
+    @mock.patch("requests_cache.backends.base.datetime")
+    @mock.patch("requests_cache.core.datetime")
+    def test_remove_expired_entries(self, datetime_mock, datetime_mock2):
+        expire_after = timedelta(minutes=10)
+        start_time = datetime.utcnow().replace(year=2010, minute=0)
+        datetime_mock.utcnow.return_value = start_time
+        datetime_mock2.utcnow.return_value = start_time
+
+        s = CachedSession(CACHE_NAME, CACHE_BACKEND, expire_after=expire_after)
+        s.get(httpbin('get'))
+        s.get(httpbin('relative-redirect/3'))
+        datetime_mock.utcnow.return_value = start_time + expire_after * 2
+        datetime_mock2.utcnow.return_value = datetime_mock.utcnow.return_value
+
+        ok_url = 'get?x=1'
+        s.get(httpbin(ok_url))
+        self.assertEqual(len(s.cache.responses), 3)
+        self.assertEqual(len(s.cache.keys_map), 3)
+        s.remove_expired_responses()
+        self.assertEqual(len(s.cache.responses), 1)
+        self.assertEqual(len(s.cache.keys_map), 0)
+        self.assertIn(ok_url, list(s.cache.responses.values())[0][0].url)
+
 
 if __name__ == '__main__':
     unittest.main()
